# notified-py

Notified-py is a simple Python library for sending notifications via different channels (email, SMS, desktop, etc.).
It aims to provide an easy-to-use interface for triggering notifications from any Python application.

### Roadmap

- [x] Basic email notification support
- [x] SMS notification support
- [ ] Desktop notification support
- [ ] Slack and webhook support
- [ ] Advanced configuration and templating
